# Table of Contents

- [application-portfolio-assessment-assess-portfolio](<./application-portfolio-assessment-assess-portfolio.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Step 3. Assess Your Application Portfolio](<./Step-3.-Assess-Your-Application-Portfolio.md>)
  - [Analyze Your Application Portfolio Using Reports](<./Step-3.-Assess-Your-Application-Portfolio/Analyze-Your-Application-Portfolio-Using-Reports.md>)
  - [Monitor Data Quality on the Architecture Executive Dashboard](<./Step-3.-Assess-Your-Application-Portfolio/Monitor-Data-Quality-on-the-Architecture-Executive-Dashboard.md>)
  - [Share Results](<./Step-3.-Assess-Your-Application-Portfolio/Share-Results.md>)
  - [Next Steps](<./Step-3.-Assess-Your-Application-Portfolio/Next-Steps.md>)
  - [Was this page helpful?](<./Step-3.-Assess-Your-Application-Portfolio/Was-this-page-helpful.md>)
